#!/usr/bin/env python

from distutils.core import setup

setup(name='ItChatSh',
      version='1.0.3',
      description='Shell on WeChat based on ItChat',
      author='LI ZEYAN',
      author_email='zy-li14@hotmail.com',
      packages=['itchatsh'],
      python_requires='>=3',
      install_requires=['itchat'],
      )
